import math
import sys
# This package can be found at: https://github.com/hydrogen18/sds1052dl-parser
import sds1052dl_parser

termination_ohms = None

print("# frequency, ch1_rms, ch2_rms, filter_voltage_drop, current_in_termination, system_impedance, filter_impedance, power_in_termination,rdb")

output = []

with open('measurements.txt') as fin:
  for line in fin:
    line = line.strip()
    if len(line) == 0:
      continue
    if '=' in line:
      name, value = line.split('=')
      if name == 'termination':
        termination_ohms = float(value.replace('ohms',''))
    else:
      data_file, freq = [x.strip() for x in line.split(',')]
      if freq.endswith('mhz'):
        freq = freq.replace('mhz', '')
        freq = 10**6.0 * float(freq)
      else:
        raise ValueError('cannot parse freq value: %s' % (freq,))
      with open(data_file) as data_fin:
        headers, data = sds1052dl_parser.parse_file(data_fin)        

        ch1_idx = headers['parsed_data_sources']['CH1']
        ch2_idx = headers['parsed_data_sources']['CH2']

        ch1_accum = 0.0 # CH1 is the signal driving the output termination
        ch2_accum = 0.0 # Ch2 is the signal driving the crystal filter
        samples = 0
        for row in data:
          ch1_accum += math.pow(row[ch1_idx], 2.0)
          ch2_accum += math.pow(row[ch2_idx], 2.0)
          samples += 1

        ch1_rms = math.sqrt( (1.0/samples) * ch1_accum )
        ch2_rms = math.sqrt( (1.0/samples) * ch2_accum )
        
        filter_voltage_drop = ch2_rms - ch1_rms

        current_in_termination = ch1_rms / termination_ohms

        system_impedance = ch2_rms / current_in_termination
        filter_impedance = system_impedance - termination_ohms
        power_in_termination = math.pow(ch1_rms, 2.0) / termination_ohms
        max_possible_power = math.pow(ch2_rms, 2.0) / termination_ohms

        rdb = 10 * math.log(power_in_termination / max_possible_power, 10)
        output.append((freq, ch1_rms, ch2_rms, filter_voltage_drop, current_in_termination, system_impedance, filter_impedance,power_in_termination,rdb,))

output = sorted(output, key = lambda x : x[0])
for row in output:
  print("%f,%f,%f,%f,%f,%f,%f,%f,%f" % row)
